1. โปรแกรมที่จำเป็นและ Font
โปรแกรมที่ต้องติดตั้ง:
•	Python – ใช้รันสคริปต์หลักในการรวมไฟล์และประมวลผลข้อมูล
•	Excel – สำหรับเปิดและตั้งค่าปริ้นต์ไฟล์ Promotion
•	SQL Server Management Studio (SSMS) – สำหรับใช้ Driver เชื่อมต่อ ตรวจสอบ และดึงข้อมูลจาก SC
Font ที่จำเป็น:
•	Bar-Code 39 – ใช้สำหรับสร้างบาร์โค้ด 39 บน Excel
•	Anuphan – ใช้สำหรับตัวอักษรไทย/อังกฤษในไฟล์ Export
การติดตั้ง Font ต้องติดตั้งในเครื่องก่อนใช้งาน Excel เพราะหากไม่มี Font จะทำให้การprint barcode หรือ เอกสาร promotion ผิดพลาดได้ สามารถ Download ได้จาก Link ด้านล่าง



2. การติดตั้งและอัปเดตโปรแกรม
ขั้นตอนติดตั้ง:
1.	เปิด Command Prompt (cmd) และพิมพ์คำสั่งเพื่อติดตั้งโปรแกรม
2.	ตรวจสอบ Version โปรแกรม
o	พิมพ์คำสั่งตรวจสอบ version และทำการติดตั้งโปรแกรม


o	หากสำเร็จ หน้าจอ cmd จะแสดงข้อความ: Successfully
3.	ตรวจสอบ Version ของโปรแกรมด้วยคำสั่งตรวจสอบ



การอัปเดตโปรแกรม:
1.	หากต้องการอัปเดต version ต้อง uninstall โปรแกรมเดิม ก่อน


2.	พิมพ์คำสั่งเพื่อลบโปรแกรม ระบบจะถามยืนยัน ให้พิมพ์ Y
3.	ติดตั้ง version ใหม่ หรือfix version ก็ได้ ให้เพิ่ม ==version ที่ต้องการ ต่อด้านหลัง


การอัปเดตจำเป็นต้องลบ version เดิมก่อน เพราะโปรแกรมอาจมี dependency หรือไฟล์ config ที่ version เก่าไม่เข้ากับ version ใหม่
3. การใช้งานโปรแกรม
รันโปรแกรมแบบ Background
1.	เปิด cmd และสั่งรันโปรแกรม   
2.	โปรแกรมจะตรวจสอบ Folder สำหรับวางไฟล์ Excel
o	หากไม่มี Folder ระบบสร้างให้อัตโนมัติ
o	หากมี Folder และมีไฟล์ Excel โปรแกรมจะเริ่มประมวลผลทันที
3.	โปรแกรมทำงานครบถ้วนจะเปิด Excel ขึ้นมาอัตโนมัติเพื่อให้ผู้ใช้ Set printer
•	การรัน Background ทำให้สามารถทำงานต่อเนื่องโดยไม่ต้องเปิดหน้าจอ UI ตลอดเวลา
การตั้งค่าปริ้นใน Excel
การตั้งค่า Print มีความสำคัญมาก เพราะไฟล์ Promotion ต้องปริ้นออกมาตามขนาด A3 และคุมข้อมูลทั้งหมดไม่ให้ตกหล่น
ขั้นตอน:
1.    ให้คลิกที่ ช่องมุม A1   แล้วทำการกด  Ctrl +Shift ค้าง แล้วทำการกดเครื่องหมาย  >  ตามด้วย เครื่องหมาย  ที่คีย์บอร์ด (คุมข้อมูลทั้งหมด) ไปที่ส่วน Manu  >> Page Layout แล้วทำการ เลือก Print Area คลิกเลือก Set Print Area 
2.   ไปที่ส่วน Manu  >> Page Layout แล้วทำการคลิกที่ Orientation แล้วทำการคลิกเลือก Landscape
3.  ไปที่ส่วน Manu  >> Page Layout แล้วทำการคลิกที่ Size set ค่า A3 
4. จากนั้น ให้คลิกเลือก Row 1 ไปที่ส่วน Manu  >> Home  >> คลิกเลือก Editing >> soft & filter
5.ไปที่ส่วน Manu  >> Page Layout ให้ค้างคุม ROW1 ไว้ก่อน และทำการเลือก Print Titles 
Tab sheet		
	Print Area	:	A1:T(Rowสุดท้าย)
	Row to repeat at Top	:	$1:$1
Tab Page		
	Orientation	:	Landscape
	page size	:	A3(297 x 420mm)
Tab Header/footer		
	Header ด้านขวา	:	ชื่อ file data(ช่อง U)
	Header กลาง	:	หน้า/จำนวนหน้าทั้งหมด
	Header ด้านซ้าย	:	วันที่ทำรายากร(ช่อง V)








6.จากนั้นกด ปิดออกมา ให้กด คลิก Page Back Preview(ด้านล่างแถว Zoom out )
7. ใช้เมาส์ ลากบริเวณ ขอบสีเทา ให้มาอยู่ที่ Column T และทำการลากเส้นปะ สีน้ำเงิน 
ออกมาที่ Column T เช่นเดียวกัน  ตรวจสอบ Row สุดท้าย ต้องไม่เป็น สีเทา
8. Filter ข้อมูล ที่ช่อง  Column V ให้เลือก วันที่ 1วันแนะนำให้เลือก วันที่ 24 ข้องรอบนั้นๆ และเลือก 
Column  U 1 ค่า แก้ Header ให้มีค่าตรงกัน 
9. จากนั้น กด เลือก File >> print ตรวจสอบหน้าที่แสดง  จากนั้นเลือก 
Scaling	:	Fix All Columns on One Page  
Print One Sided	:	Print on Both Sides    
Printer Properties. Print paper Size	:	A3

10.กด  ตกลง และกด Print เลือก Filter ที่  Column  U ค่าถัดทัน แก้ Herder แล้วสั่งปริ้น วนซ้ำ จนครบทุก File และทุก





1.	คำสั่งเปิดหน้าจอ UI APP Desktop ให้พิมพ์คำสั่ง


•	ระบบจะเปิด UI ขึ้นมาแสดง สามารถ Set ค่าเพิ่มเติมได้ จากนั้นให้กด Import file และเลือก file ที่ต้องการนำเข้า จากนั้นกดยืนยัน รอจนกว่า Excel จะเปิดขึ้นมา และทำการ Set ค่า ปริ้นตามข้อมูลด้านบน 
4.การตรวจสอบ Report การทำงาน 
Connect database  ไปที่ Tabel Report Filter ตามค่า ช่อง Version  ข้อมูลที่ตรวจสอบ 
1. Column  Status = S แปลว่า Insert ข้อมูลสำเร็จ ให้ตรวจสอบ Column COU_ROW_INIT ต้องเท่ากับ Column  COU_COL_CUT  ต้องเท่ากันทุกค่า   ช่อง Remark ต้องว่างเสมอ กรณี แสดงข้อมูล file หรือ Sheet นั้นมีปัญหา ให้ตรวจสอบ ข้อมูลในไฟล์นั้น
2.ตรวจสอบ . Column  Status = 0 แปลว่าค่าค่าไม่ได้ ข้อมูลไม่ Math กัน ให้ตรวจสอบ Check  sheet ที่ชื่อ ดู แปลกๆ เช่น 1 ชิ้น เหรียญ  , On top All member sheet พวกนี้ส่วนใหญ่ ต้องสำเร็จ ให้ตรวจสอบ ข้อมูลในไฟล์อย่างถี่ถ้วน
3 . ทำการแจ้งข้อมูล Summary ทุกครั้ง เพื่อยืนยันข้อมูลที่ถูกต้อง จำนวน File ทั้งหมด ,จำนวน Sheet ทั้งหมด ,จำนวน Sheet ที่ False ทั้งหมด จำนวน ทั้งหมด 
5.การบันทึกข้อมูล  
1.    Manul  จด Note  ค่าไคร Test sheet file ไหนวันที่เท่าไหนให้ได้มากที่สุด 
1.	รันคำสั่ง ให้ดึงข้อมูลจากเครื่องที่เทสมา เก็บไว้สามารถ Export ออกมาดูได้ว่าไครเทสได้เท่าไหร่
ตรวจสอบข้อมูล Product  ที่ไม่มี Barcode ให้เข้าลิงค์ด้านล่าง 


2.	Login เข้าสู่ระบบ ให้คลิกเลือกเมนู  Item Info เลือก Inquiry Item By Store (HQ)  
3.  ระบบจะแสดงหน้าจอ POP -UP ขึ้นมา ให้ทำการกรอกข้อมูลค้นหาดังนี้
	
Input		
	Store id	:	A1:T(Rowสุดท้าย)
	Item id		
	Barcode ID		
	Effective Date 	:	$1:$1
Tab Page		
	Orientation	:	Landscape
	page size	:	A3(297 x 420mm)
Tab Header/footer		
	Header ด้านขวา	:	ชื่อ file data(ช่อง U)
	Header กลาง	:	หน้า/จำนวนหน้าทั้งหมด
	Header ด้านซ้าย	:	วันที่ทำรายากร(ช่อง V)

กรณี ลง Information ใหม่ แล้ว Map ข้อมูลใหม่ ให้ เข้า Database SQL SERVER จากนั้นให้รันคำสั่ง 

เมื่อ รันให้นำข้อมูลที่ได้ วางที่ Excel สร้าง Sheet สำหรับเก็บ จากนั้น ให้ไปที่ Column barcode และใส่สูตร Excel ที่ช่อง 
จากนั้นทำที่ช่อง Barcode 39 ตามสูตรด้านล่าง

 
กรณี Error  ในระหว่างสั่ง Print
1.	กรณี กระดาษติด ให้ตรวจสอบว่า กระดาษติดบริเวณไหนและ ให้เปิดเครื่องด้านข้างออกมา Check  และให้ดึงกระดาษที่ติดออกมาให้หมด  เมื่อ ปิดทุกอย่างเรียบร้อย ระบบจะทำงานต่อ
2.	กรณี หมึกหมด หรือ กระดาษหมด ให้ เติม หมึก กระดาษ กรณี เติมกระดาษ ที่หน้าจอจะแสดง  pop-up ขึ้นมาถาม ให้ ตอบ Yes ในกรณี ตอบ No.  ให้เลือกรูปแบบกระดาษตามที่ใส่ เมื่อเติม เรียบร้อย ให้ Login เข้าเครื่อง ใหม่ อีกครั้งเครื่องจะข้าม คิวงานเราเรียบร้อยแล้ว  จากนั้น ให้ สังเกต สัญลักษณ์ แจ้งเตื่อน เครื่องหมายตกใจ ที่เด้งบนหน้าจอ ให้คลิกเข้าไป จะเห็น  Status งานที่สั่งปริ้น ให้หา คำสั่งปริ้น ที่ปริ้นค้างไว้ และกด Print ต่อ และ ค่อยๆเลือก คำสั่งอื่นๆ จนครบ 
เคสที่อาจทำให้ Error ได้
1. เครื่องไม่มี Excel 
2. เครื่องไม่มีสิทธิ์เข้าถึง เครื่อง SC 
** หมายเหตุ 
1. การSet ปริ้น ควรทำให้ละเอียด เนื่องจาก กรณี ชื่อ File หรือ วันที่ ผิด อาจทำให้กดการ ตกหล่น หาย ได้ กรณีต้องการค้นหา อาจไม่พบข้อมู อาจเป็นไปได้ถึงปริ้นข้าง ไป หรือ set  print ไม่ครบ ความผิดจะตกกับคนเอกสาร 
2.กรณี ชื่อไฟล์ซ้ำหรือ ข้อมูลมีจำนวนน้อยแปลกๆ ให้ เอะใจ file เอกสารที่ส่งมาอาจเสียหายได้ ให้สังเกต แจ้งเตือน Report ที่หน้า Ui กรณีนำไฟล์ไปรวมไม่ครบ ไม่ได้ปริ้น ออกมา ความผิดจะตกกับคนเอกสาร Promotionที่ผิดบ่อย คือโปรที่ไม่มีไครเทส	
3.ตรวจสอบ Product กรณีที่ข้อมูล Barcode ไม่มีจำนวนมาก ให้ลองดึงจากเครื่องอื่นหรือลง Information และดึงจากเครื่องตัวเองก็ได้ ข้อมูลอาจไม่อัพเดท  กรณี จะทำให้คนเทสๆเทสได้ช้าลง
